==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/General/hal/translations/hal_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>HAL Module</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Over de HAL Module</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>HAL Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Deze module faciliteert detectie van verwisselbare apparaten, gebruikmakend van HAL (Verouderd, gebruik UDisks module)</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Gebasseerd op Solid (KDE hardware bibliotheek)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Voeg CD &quot;%1&quot; toe</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Voeg Station &quot;%1&quot; toe</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>CD Audio Detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Voeg nummers automatisch toe aan speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Verwijder nummers automatisch van speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detectie van Verwisselbare Stations</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Voeg bestanden automatisch toe aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Verwijder bestanden automatisch van afspeellijst</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/hal/translations/hal_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>HAL Module</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>Over de HAL Module</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>HAL Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Deze module faciliteert detectie van verwisselbare apparaten, gebruikmakend van HAL (Verouderd, gebruik UDisks module)</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Gebasseerd op Solid (KDE hardware bibliotheek)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Voeg CD &quot;%1&quot; toe</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Voeg Station &quot;%1&quot; toe</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>CD Audio Detectie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Voeg nummers automatisch toe aan speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Verwijder nummers automatisch van speellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detectie van Verwisselbare Stations</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Voeg bestanden automatisch toe aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Verwijder bestanden automatisch van afspeellijst</translation>
    </message>
</context>
</TS>
